@@ -1,7 +1,7 @@
 # -*- Perl -*-
 # a means to segment MIDI by equal duration
 package MIDI::Segment;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use 5.10.0;
 use strict;
 use warnings;
@@ -80,7 +80,8 @@ sub _durations {
 }
 
 sub _possible_segments {
-    my ( $half, $tracks ) = @_;
+    my ( $max, $tracks ) = @_;
+    my $half = int( $max / 2 );
     my %possible;
   TRACK: for my $onsets (@$tracks) {
         # TODO or die here, if this is reachable somehow sane
@@ -100,7 +101,8 @@ sub _possible_segments {
         }
         @possible{ @{$onsets}[ 0 .. $midpoint - 1 ] } = ();
     }
-    return [ sort { $a <=> $b } keys %possible ];
+    # and only those possible that evenly split the duration
+    return [ sort { $a <=> $b } grep { $max % $_ == 0 } keys %possible ];
 }
 
 sub new {
@@ -111,7 +113,7 @@ sub new {
     die "problematic MIDI v=$self->{vague} r=$self->{ragged}"
       if $self->{vague} or $self->{ragged};
     my $potential =
-      _possible_segments( int( $self->{maximum} / 2 ), $self->{onsets} );
+      _possible_segments( $self->{maximum}, $self->{onsets} );
   DURATION: for my $dur (@$potential) {
         my $window = $dur;
         while ( $window < $self->{maximum} ) {
